@@ -11,6 +11,7 @@ from tempfile import NamedTemporaryFile
 
 import cv2
 import skvideo.io
+from tqdm import tqdm
 
 from pybsc.timestamp_utils import get_timestamp_indices_wrt_base
 
@@ -66,7 +67,8 @@ def get_video_n_frame(video_path):
 
 def split_video(video_file_path, output_path=None,
                 start_time=None, end_time=None,
-                hflip=False, vflip=False):
+                hflip=False, vflip=False,
+                out_to_null=True):
     if start_time is None and end_time is None:
         raise ValueError
     start_time = start_time or 0.0
@@ -80,17 +82,31 @@ def split_video(video_file_path, output_path=None,
         command.extend(['-vf', 'hflip'])
     if vflip is True:
         command.extend(['-vf', 'vflip'])
+
+    stdout = None
+    stderr = None
+    if out_to_null:
+        stdout = subprocess.DEVNULL
+        stderr = subprocess.DEVNULL
     if output_path is None:
         suffix = Path(video_file_path).suffix
         with NamedTemporaryFile(delete=True, suffix=suffix) as tmp:
             command.append(tmp.name)
-            print(f'Running \"{" ".join(command)}\"')
-            subprocess.call(command)
+            if not out_to_null:
+                print(f'Running \"{" ".join(command)}\"')
+            proc = subprocess.Popen(command,
+                                    stdout=stdout,
+                                    stderr=stderr)
+            proc.wait()
             shutil.copy(tmp.name, video_file_path)
     else:
         command.append(str(output_path))
-        print(f'Running \"{" ".join(command)}\"')
-        subprocess.call(command)
+        if not out_to_null:
+            print(f'Running \"{" ".join(command)}\"')
+        proc = subprocess.Popen(command,
+                                stdout=stdout,
+                                stderr=stderr)
+        proc.wait()
 
 
 def split_video_from_stamps(
@@ -98,7 +114,8 @@ def split_video_from_stamps(
         start_stamps, end_stamps,
         output_paths=None,
         output_dirpath=None,
-        filename_tmpl='video_{start_frame:05}_{end_frame:05}.mp4'):
+        filename_tmpl='video_{start_frame:05}_{end_frame:05}.mp4',
+        show_progress=True):
     if len(start_stamps) != len(end_stamps):
         raise RuntimeError(
             'Length not much len(start_stamps) != len(end_stamps)'
@@ -112,7 +129,10 @@ def split_video_from_stamps(
             os.makedirs(tmp_output_dir.name, exist_ok=True)
             output_dirpath = tmp_output_dir.name
         output_dirpath = Path(output_dirpath)
-        for i, (s, e) in enumerate(zip(start_stamps, end_stamps)):
+        for i, (s, e) in tqdm(
+                enumerate(zip(start_stamps, end_stamps)),
+                total=len(min(start_stamps, end_stamps)),
+                disable=show_progress is False):
             start_frame = int(math.ceil(s * fps))
             end_frame = int(math.ceil(e * fps))
             output_paths.append(output_dirpath
